FlutterxelBindings class
Bindings for src/flutterxel.h.
Regenerate bindings with dart run ffigen --config ffigen.yaml.
Constructors
- FlutterxelBindings(DynamicLibrary dynamicLibrary)
-
The symbols are looked up in
dynamicLibrary. -
FlutterxelBindings.fromLookup(Pointer<
T> lookup<T extends NativeType>(String symbolName) ) -
The symbols are looked up with
lookup.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
flutterxel_core_atan2(
double y, double x) → double -
flutterxel_core_backend_kind(
) → int -
flutterxel_core_blt(
double x, double y, int img, double u, double v, double w, double h, int colkey, double rotate, double scale) → bool -
flutterxel_core_bltm(
double x, double y, int tm, double u, double v, double w, double h, int colkey) → bool -
flutterxel_core_btn(
int key) → bool -
flutterxel_core_btnp(
int key, int hold, int period) → bool -
flutterxel_core_btnr(
int key) → bool -
flutterxel_core_btnv(
int key) → int -
flutterxel_core_camera(
int x, int y) → bool -
flutterxel_core_ceil(
double x) → int -
flutterxel_core_circ(
int x, int y, int r, int col) → bool -
flutterxel_core_circb(
int x, int y, int r, int col) → bool -
flutterxel_core_clamp_f64(
double x, double lower, double upper) → double -
flutterxel_core_clamp_i64(
int x, int lower, int upper) → int -
flutterxel_core_clip(
int x, int y, int w, int h) → bool -
flutterxel_core_cls(
int col) → bool -
flutterxel_core_color_mode(
) → int -
flutterxel_core_copy_framebuffer(
Pointer< Int32> dst, int dst_len) → bool -
flutterxel_core_cos(
double deg) → double -
flutterxel_core_dither(
double alpha) → bool -
flutterxel_core_elli(
int x, int y, int w, int h, int col) → bool -
flutterxel_core_ellib(
int x, int y, int w, int h, int col) → bool -
flutterxel_core_fill(
int x, int y, int col) → bool -
flutterxel_core_flip(
) → bool -
flutterxel_core_floor(
double x) → int -
flutterxel_core_frame_count(
) → int -
flutterxel_core_framebuffer_len(
) → int -
flutterxel_core_framebuffer_ptr(
) → Pointer< Int32> -
flutterxel_core_fullscreen(
bool enabled) → bool -
flutterxel_core_icon(
Pointer< Char> data, int scale, int colkey) → bool -
flutterxel_core_image_cls(
int img, int col) → bool -
flutterxel_core_image_pget(
int img, int x, int y, Pointer< Int32> col_out) → bool -
flutterxel_core_image_pset(
int img, int x, int y, int col) → bool -
flutterxel_core_image_replace(
int img, Pointer< Int32> data, int len) → bool -
flutterxel_core_init(
int width, int height, Pointer< Char> title, int fps, int quit_key, int display_scale, int capture_scale, int capture_sec) → bool -
flutterxel_core_integer_scale(
bool enabled) → bool -
flutterxel_core_is_channel_playing(
int ch) → bool -
flutterxel_core_line(
int x1, int y1, int x2, int y2, int col) → bool -
flutterxel_core_load(
Pointer< Char> filename, int exclude_images, int exclude_tilemaps, int exclude_sounds, int exclude_musics) → bool -
flutterxel_core_load_pal(
Pointer< Char> filename) → bool -
flutterxel_core_mouse(
bool visible) → bool -
flutterxel_core_music_set_seq(
int msc, int ch, Pointer< Int32> seq_ptr, int seq_len) → bool -
flutterxel_core_noise(
double x, double y, double z) → double -
flutterxel_core_nseed(
int seed) → bool -
flutterxel_core_num_colors(
) → int -
flutterxel_core_pal(
int col1, int col2) → bool -
flutterxel_core_perf_monitor(
bool enabled) → bool -
flutterxel_core_pget(
int x, int y) → int -
flutterxel_core_play(
int ch, int snd_kind, int snd_value, Pointer< Int32> snd_sequence_ptr, int snd_sequence_len, Pointer<Char> snd_string, double sec, int loop, int resume) → bool -
flutterxel_core_play_pos(
int ch, Pointer< Int32> snd, Pointer<Double> pos) → bool -
flutterxel_core_playm(
int msc, bool loop) → bool -
flutterxel_core_pset(
int x, int y, int col) → bool -
flutterxel_core_quit(
) → bool -
flutterxel_core_rect(
int x, int y, int w, int h, int col) → bool -
flutterxel_core_rectb(
int x, int y, int w, int h, int col) → bool -
flutterxel_core_reset(
) → bool -
flutterxel_core_reset_screencast(
) → bool -
flutterxel_core_rndf(
double a, double b) → double -
flutterxel_core_rndi(
int a, int b) → int -
flutterxel_core_rseed(
int seed) → bool -
flutterxel_core_run(
FlutterxelCoreFrameCallback update, Pointer< Void> update_user_data, FlutterxelCoreFrameCallback draw, Pointer<Void> draw_user_data) → bool -
flutterxel_core_save(
Pointer< Char> filename, int exclude_images, int exclude_tilemaps, int exclude_sounds, int exclude_musics) → bool -
flutterxel_core_save_pal(
Pointer< Char> filename) → bool -
flutterxel_core_screen_mode(
int scr) → bool -
flutterxel_core_screencast(
int scale) → bool -
flutterxel_core_screenshot(
int scale) → bool -
flutterxel_core_set_btn_state(
int key, bool pressed) → bool -
flutterxel_core_set_btn_value(
int key, int value) → bool -
flutterxel_core_set_color_mode(
int color_mode) → bool -
flutterxel_core_set_num_colors(
int num_colors) → bool -
flutterxel_core_sgn_f64(
double x) → double -
flutterxel_core_sgn_i64(
int x) → int -
flutterxel_core_show(
) → bool -
flutterxel_core_sin(
double deg) → double -
flutterxel_core_sound_set_effects(
int snd, Pointer< Int32> effects_ptr, int effects_len) → bool -
flutterxel_core_sound_set_notes(
int snd, Pointer< Int32> notes_ptr, int notes_len) → bool -
flutterxel_core_sound_set_speed(
int snd, int speed) → bool -
flutterxel_core_sound_set_tones(
int snd, Pointer< Int32> tones_ptr, int tones_len) → bool -
flutterxel_core_sound_set_volumes(
int snd, Pointer< Int32> volumes_ptr, int volumes_len) → bool -
flutterxel_core_sqrt(
double x) → double -
flutterxel_core_stop(
int ch) → bool -
flutterxel_core_text(
int x, int y, Pointer< Char> text, int col) → bool -
flutterxel_core_tilemap_cls(
int tm, int tile_x, int tile_y) → bool -
flutterxel_core_tilemap_pget(
int tm, int x, int y, Pointer< Int32> tile_x_out, Pointer<Int32> tile_y_out) → bool -
flutterxel_core_tilemap_pset(
int tm, int x, int y, int tile_x, int tile_y) → bool -
flutterxel_core_tilemap_set_imgsrc(
int tm, int imgsrc) → bool -
flutterxel_core_title(
Pointer< Char> title) → bool -
flutterxel_core_tri(
int x1, int y1, int x2, int y2, int x3, int y3, int col) → bool -
flutterxel_core_trib(
int x1, int y1, int x2, int y2, int x3, int y3, int col) → bool -
flutterxel_core_version_major(
) → int -
flutterxel_core_version_minor(
) → int -
flutterxel_core_version_patch(
) → int -
flutterxel_core_warp_mouse(
double x, double y) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited