FlutterxelCorePlaySndKind enum
Optional parameter encoding in ABI:
- optional int32: INT32_MIN means None
- optional float64: NaN means None
- optional bool: -1 means None, 0 means false, 1 means true
Values
- FLUTTERXEL_CORE_PLAY_SND_INT → const FlutterxelCorePlaySndKind
-
const FlutterxelCorePlaySndKind(0) - FLUTTERXEL_CORE_PLAY_SND_INT_LIST → const FlutterxelCorePlaySndKind
-
const FlutterxelCorePlaySndKind(1) - FLUTTERXEL_CORE_PLAY_SND_STRING → const FlutterxelCorePlaySndKind
-
const FlutterxelCorePlaySndKind(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → FlutterxelCorePlaySndKind
Constants
-
values
→ const List<
FlutterxelCorePlaySndKind> - A constant List of the values in this enum, in order of their declaration.